==> mx_0.4.0.orig.tar.gz: mx-0.4.0/mx/mx.h <==
/*
 * mx.h: Collection of high-level actors for Clutter
 *
 * Copyright 2009, 2010 Intel Corporation.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU Lesser General Public License,
 * version 2.1, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
 * Boston, MA 02111-1307, USA.
 *
 */

#ifndef __MX_H__
#define __MX_H__

#define MX_H_INSIDE

#include <mx/mx-action.h>
#include <mx/mx-adjustment.h>
#include <mx/mx-application.h>
#include <mx/mx-bin.h>
#include <mx/mx-box-layout.h>
#include <mx/mx-box-layout-child.h>
#include <mx/mx-button.h>
#include <mx/mx-button-group.h>
#include <mx/mx-combo-box.h>
#include <mx/mx-draggable.h>
#include <mx/mx-droppable.h>
#include <mx/mx-clipboard.h>
#include <mx/mx-entry.h>
#include <mx/mx-enum-types.h>
#include <mx/mx-expander.h>
#include <mx/mx-floating-widget.h>
#include <mx/mx-frame.h>
#include <mx/mx-grid.h>
#include <mx/mx-icon.h>
#include <mx/mx-item-factory.h>
#include <mx/mx-item-view.h>
#include <mx/mx-list-view.h>
#include <mx/mx-label.h>
#include <mx/mx-notebook.h>
#include <mx/mx-popup.h>
#include <mx/mx-progress-bar.h>
#include <mx/mx-scroll-bar.h>
#include <mx/mx-scroll-view.h>
#include <mx/mx-scrollable.h>
#include <mx/mx-slider.h>
#include <mx/mx-stylable.h>
#include <mx/mx-style.h>
#include <mx/mx-subtexture.h>
#include <mx/mx-table.h>
#include <mx/mx-table-child.h>
#include <mx/mx-texture-cache.h>
#include <mx/mx-texture-frame.h>
#include <mx/mx-toggle.h>
#include <mx/mx-toolbar.h>
#include <mx/mx-tooltip.h>
#include <mx/mx-types.h>
#include <mx/mx-utils.h>
#include <mx/mx-version.h>
#include <mx/mx-viewport.h>
#include <mx/mx-widget.h>

#undef MX_H_INSIDE

#endif /* __MX_H__ */

==> mx_1.0.2.orig.tar.gz: mx-1.0.2/mx/mx.h <==
/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
/*
 * mx.h: Collection of high-level actors for Clutter
 *
 * Copyright 2009, 2010 Intel Corporation.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU Lesser General Public License,
 * version 2.1, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
 * Boston, MA 02111-1307, USA.
 *
 */

#ifndef __MX_H__
#define __MX_H__

#define MX_H_INSIDE

#include <mx/mx-action.h>
#include <mx/mx-adjustment.h>
#include <mx/mx-application.h>
#include <mx/mx-bin.h>
#include <mx/mx-box-layout.h>
#include <mx/mx-box-layout-child.h>
#include <mx/mx-button.h>
#include <mx/mx-button-group.h>
#include <mx/mx-combo-box.h>
#include <mx/mx-deform-texture.h>
#include <mx/mx-deform-bow-tie.h>
#include <mx/mx-deform-page-turn.h>
#include <mx/mx-deform-waves.h>
#include <mx/mx-draggable.h>
#include <mx/mx-droppable.h>
#include <mx/mx-clipboard.h>
#include <mx/mx-entry.h>
#include <mx/mx-enum-types.h>
#include <mx/mx-expander.h>
#include <mx/mx-floating-widget.h>
#include <mx/mx-focus-manager.h>
#include <mx/mx-focusable.h>
#include <mx/mx-frame.h>
#include <mx/mx-grid.h>
#include <mx/mx-icon.h>
#include <mx/mx-icon-theme.h>
#include <mx/mx-item-factory.h>
#include <mx/mx-item-view.h>
#include <mx/mx-list-view.h>
#include <mx/mx-label.h>
#include <mx/mx-notebook.h>
#include <mx/mx-offscreen.h>
#include <mx/mx-path-bar.h>
#include <mx/mx-menu.h>
#include <mx/mx-progress-bar.h>
#include <mx/mx-scroll-bar.h>
#include <mx/mx-scroll-view.h>
#include <mx/mx-scrollable.h>
#include <mx/mx-slider.h>
#include <mx/mx-stylable.h>
#include <mx/mx-style.h>
#include <mx/mx-table.h>
#include <mx/mx-table-child.h>
#include <mx/mx-texture-cache.h>
#include <mx/mx-texture-frame.h>
#include <mx/mx-toggle.h>
#include <mx/mx-toolbar.h>
#include <mx/mx-tooltip.h>
#include <mx/mx-types.h>
#include <mx/mx-utils.h>
#include <mx/mx-version.h>
#include <mx/mx-viewport.h>
#include <mx/mx-widget.h>
#include <mx/mx-window.h>

#undef MX_H_INSIDE

#endif /* __MX_H__ */
